0.9.9 API documentation: GLM_GTX_transform

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_transform
Experimental extensions

Include <glm/gtx/transform.hpp> to use the features of this extension. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | rotate (T angle, vec< 3, T, Q > const &v)
| Builds a rotation 4 * 4 matrix created from an axis of 3 scalars and an angle expressed in radians. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | scale (vec< 3, T, Q > const &v)
| Transforms a matrix with a scale 4 * 4 matrix created from a vector of 3 components. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | translate (vec< 3, T, Q > const &v)
| Transforms a matrix with a translation 4 * 4 matrix created from 3 scalars. More...

## Detailed Description

Include <glm/gtx/transform.hpp> to use the features of this extension.

Add transformation matrices

## Function Documentation

GLM_FUNC_DECL mat<4, 4, T, Q> glm::rotate | ( | T | angle,
|  | vec< 3, T, Q > const & | v
| ) |  |

Builds a rotation 4 * 4 matrix created from an axis of 3 scalars and an angle expressed in radians.

See also
  GLM_GTC_matrix_transform
  GLM_GTX_transform

GLM_FUNC_DECL mat<4, 4, T, Q> glm::scale | ( | vec< 3, T, Q > const & | v | ) |

Transforms a matrix with a scale 4 * 4 matrix created from a vector of 3 components.

See also
  GLM_GTC_matrix_transform
  GLM_GTX_transform

GLM_FUNC_DECL mat<4, 4, T, Q> glm::translate | ( | vec< 3, T, Q > const & | v | ) |

Transforms a matrix with a translation 4 * 4 matrix created from 3 scalars.

See also
  GLM_GTC_matrix_transform
  GLM_GTX_transform